/**********************************************************************************************
* Device      : AD18E22X
* Author      : 
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 配置看门狗使能以及看门狗溢出时间和上电延时时间来控制系统何时溢出复位
*               现象：进入主程序后先是PB0进行翻转，一段时间后PB0停止翻转，改成PB1进行翻转
*               若不完成清看门狗，时间溢出复位后主程序会重头开始执行
*               若配置为禁止看门狗溢出复位，则超时也不会发生复位
***********************************************************************************************/

#include "AD18E22X.h"
#include <stdio.h>
#include "AD18E22X_DEF.h"

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_OFF_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_ON_2L     & _TWDT_101_2L   );
//---------配置字 WDTE 可选--------------
//_WDTE_ON_2L          使能看门狗复位
//_WDTE_OFF_2L         禁止看门狗复位
//------------------------
//通过配置TWDT可以配置WDT溢出时间
//配置方式(未使用分频)：   _TWDT_000_2L   _TWDT_001_2L  _TWDT_010_2L   _TWDT_011_2L：15个时钟周期
//                        _TWDT_100_2L 62.24ms  _TWDT_101_2L 246.56ms   _TWDT_110_2L 4.03ms  _TWDT_111_2L 31.5ms


//------------------------
//注：若配置字中使能了WDT则上电延时时间不可大于WDT时间，否则无法进入主函数。如选择延时为31.5ms时，WDT溢出时间只可选择31.5ms及以上。

void GPIO_Init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象 	
}

void main(void)
{
    unsigned char i;
	GPIO_Init();
	TRISB0 = 0;  TRISB1 = 0;            //设置PB0和PB1为输出
  
    PCON &= (7<<1);
    PCON |= PREDIV_WDT_DIS1;
	CLRWDT();           	//分频配置完后需要清狗(或者配置字关闭看门狗,WDTE = 1就无需清狗)
	// WDTEN = 1;            //WDTEN=1或配置字中WDTE选择_WDTE_ON_2L 都可使能WDT
    //PREDIV[2:0]=0;	//WDT 1分频
    //PREDIV[2:0]=1;	//WDT 2分频
	//PREDIV[2:0]=2;	//WDT 3分频
	//PREDIV[2:0]=3;	//WDT 4分频
	//PREDIV[2:0]=4;	//WDT 5分频
	//PREDIV[2:0]=5;	//WDT 6分频
	//PREDIV[2:0]=6;	//WDT 7分频
	//PREDIV[2:0]=7;	//WDT 8分频
    for(i = 0;i<100;i++)
    {
      PB0 = ~PB0;             //PB0翻转数次
      __delay_ms(1);
    }

	while(1)
	{
		PB0 = 0;
	    PB1 = ~PB1;             //PB1翻转数次

	    //  CLRWDT();           //清狗

	}
}

//高优先级中断服务函数
void interrupt ISR_h (void)
{

}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{

}

