/*******************************************************************************
* Device      : AD18E22X
* Author      : Sunwangzhi
* Version     : V0.0.1
* Date        : 2024.08.24
* Description : 可配置Timer2的预分频和后分频
********************************************************************************/

#include "AD18E22X.h"
#include "AD18E22X_DEF.h"

/*********************************************************************************************
*常用配置字功能说明:
*
*_FINTOSC_DIV1_1L  :  内部 RC 振荡器频率选择
*_FCPU_4T_1L       :  选择指令周期为4T模式
*_SMT_SMV_1L       :  电平选择位
*_LVREN_OFF_1L     :  LVR 使能选择           
*_LVR24V_1L        :  LVR 电压选择2.4V    
*
*_DBGEN_I2C_OFF_2L :  I2C 调试模式使能选择               
*_DBGEN_UART_00_2L :  UART 调试模式使能选择              
*_RESETE_OFF_2L    :  外部复位使能选择           
*_WDTE_OFF_2L      :  WDT 使能选择         
*_TWDT_111_2L      :  看门狗溢出时间及上电复位时间选择         
*
*注意：1.配置字若无特别需求请勿修改；
*      2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _FCPU_4T_1L         & _SMT_SMV_1L     & _LVREN_OFF_1L    & _LVR24V_1L  );
__CONFIG(2,_DBGEN_I2C_ON_2L     & _DBGEN_UART_00_2L    & _RESETE_OFF_2L  & _WDTE_OFF_2L     & _TWDT_111_2L   );


void GPIO_Init(void);
void Timer2_div(unsigned char T2_CKPS,unsigned char T2_OUTPS);
void Timer2_Init(void);

//==============================================================================================
// ----Function: 主程序
// --Parameters: None
// -----Returns: None
//---------Note: 选择Timer2预分频值为8和后分频值为4
//==============================================================================================

void main (void)
{
	GPIO_Init();     //所有IO初始化
	Timer2_Init();    //timer2 配置初始化
	//	预分频1:4     后分频1:4
	Timer2_div(T2CKPS_DIV4,   T2OUTPS(4));     //可根据需求配置预分频值与后分频值
	TMR2ON=1;   //使能timer2计数

	IPEN = 1;	   	//中断优先级
	PEIE = 0;    	//外设GIEL
    GIEH = 1;
	while(1);

}


//高优先级中断服务函数
void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断
	if(TMR2IF  &&  TMR2IE)      //f = 250Hz
	{
		TMR2IF = 0;		 //timer2中断标志位清0
	    PB3    =~PB3;		//PB3翻转
	}

}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//进入中断后系统自动关闭中断

}

/*******************************************************************************
// ----Function: GPIO_Init
// --Parameters:
// -----Returns: None
//---------Note:所有IO初始化
*******************************************************************************/

void GPIO_Init(void)
{
     TRISA = 0X00;       //PA口设置为输出模式
     PA0PU = 1;          //PA0上拉关闭
     PA1PU = 1;          //PA1上拉关闭
     PA2PU = 1;          //PA2上拉关闭
     PA4PU = 1;          //PA4上拉关闭
     PA5PU = 1;          //PA5上拉关闭
     PAPD  = 0x3F;       //PA口下拉关闭
     PA0OD = 0;          //PA0 OD关闭
     PA1OD = 0;          //PA1 OD关闭
     PA2OD = 0;          //PA2 OD关闭
     PA4OD = 0;          //PA4 OD关闭
     PA5OD = 0;          //PA5 OD关闭
     TRISB = 0X00;       //PB口设置为输出模式
     PBPU  = 0x3F;       //PB口上拉关闭
     TRISC = 0X00;       //PC口设置为输出模式
     PCPU  = 0x7F;       //PC上拉关闭
     PC6=1;              //注：PC6在低功耗模式下需要关闭上拉并且输出高
     PC6PD = 1;          //PC6口下拉关闭  PC6控制PMOS时需要设置成输入模式，
                         //通过控制上下拉电阻1K实现PMOS开关，减少PMOS开关导致电源电压过充现象 
}

/*******************************************************************************
 * 【T2_CKPS】:TIMER2的输入时钟分频
 *                    T2CKPS_DIV1    TIMER2输入时钟1:1分频
 *                    T2CKPS_DIV4    TIMER2输入时钟1:4分频
 *                    T2CKPS_DIV8    TIMER2输入时钟1:8分频
 *                    T2CKPS_DIV16   TIMER2输入时钟1:16分频
 * 【T2_OUTPS】: TIMER2的输入时钟后分频
 * 					  T2OUTPS(x)    x:分频选择，x取值范围：1~32
*******************************************************************************/
void Timer2_div(unsigned char T2_CKPS,unsigned char T2_OUTPS)
{

	T2CON0 = 0;
	T2CON0 |= T2_CKPS ;   //预分频
	T2CON0 |= T2_OUTPS;   //后分频
    TMR2IF = 0;
    TMR2IP = 1;
    TMR2IE = 1;
}
/*******************************************************************************
// ----Function: Timer2_Init
// --Parameters:
// -----Returns: None
//---------Note:所有IO初始化
*******************************************************************************/
void Timer2_Init(void)
{
	PR2 = 0X63;    	//周期
	TMR2  = 0X00;	//初值
}
